<?php
/**
 * @copyright	Copyright (C) 2013 Omar Ramos. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

/**
 * Limit Registrations User plugin
 *
 * @package		Joomla.Plugin
 * @subpackage	User.joomla
 * @since		1.5
 */
class plgUserLimitRegistrations extends JPlugin
{

	/**
	 * Utility method to act on a user before it has been saved.
	 *
	 * This method sends a registration email to new users created in the backend.
	 *
	 * @param	array		$user		Holds the new user data.
	 * @param	boolean		$isnew		True if a new user is stored.
	 *
	 * @return	void
	 * @since	1.6
	 */
	public function onUserBeforeSave($user, $isnew)
	{
		// Initialise variables.
		$app	= JFactory::getApplication();
		$config	= JFactory::getConfig();
		$mail_to_user = $this->params->get('mail_to_user', 1);

		if ($isnew)
		{
			if ($app->isSite())
			{
				// Load user_joomla plugin language (not done automatically).
				$lang = JFactory::getLanguage();
				$lang->load('plg_user_limitregistrations', JPATH_ADMINISTRATOR);

				// Create the empty Cleaned List Containers:
				$cleanedTLDs = array();
				$cleanedDomains = array();

				// Retrieve and clean the Allowed TLDs List:
				$allowedTLDsString = $this->params->get('allowed_tlds', '');
				$allowedTLDsString = JString::trim($allowedTLDsString);

				if (!empty($allowedTLDsString))
				{
					$allowedTLDs = explode("\r\n", $allowedTLDsString);
					foreach($allowedTLDs as $allowedTLD)
					{
						$allowedTLD = JString::trim($allowedTLD);
						$allowedTLD = JString::ltrim($allowedTLD, '.');
						$allowedTLD = JString::rtrim($allowedTLD, '.');
						$cleanedTLDs[] = $allowedTLD;
					}
				}

				// Retrieve and clean the Allowed Domains List:
				$allowedDomainsString = $this->params->get('allowed_domains', '');
				$allowedDomainsString = JString::trim($allowedDomainsString);

				if (!empty($allowedDomainsString))
				{
					$allowedDomains = explode("\r\n", $allowedDomainsString);
					foreach($allowedDomains as $allowedDomain)
					{
						$allowedDomain = JString::trim($allowedDomain);
						$allowedDomain = JString::ltrim($allowedDomain, '.');
						$allowedDomain = JString::rtrim($allowedDomain, '.');
						$cleanedDomains[] = $allowedDomain;
					}
				}

				// Get the user data.
				$requestData = JRequest::getVar('jform', array(), 'post', 'array');

				$email1 = $requestData['email1'];
				if (filter_var($email1, FILTER_VALIDATE_EMAIL))
				{
					$emailParts = explode('@', $email1);
					$emailUsername = $emailParts[0];
					$emailDomain = $emailParts[1];

					$emailDomainParts = explode('.', $emailDomain);
					$emailTLD = array_pop($emailDomainParts);

					// Short circuit if both switches are turned off:
					if (!$this->params->get('allowed_tlds_switch', 0) && !$this->params->get('allowed_domains_switch', 0))
					{
						return true;
					}

					$results = array();
					if ($this->params->get('allowed_tlds_switch', 0))
					{
						$results[] = in_array($emailTLD, $cleanedTLDs);
					}


					if ($this->params->get('allowed_domains_switch', 0))
					{
						$results[] = in_array($emailDomain, $cleanedDomains);
					}

					// Final Result: Check to see if either check returned true:
					$finalResult = in_array(true, $results, true);

					if ($finalResult)
					{
						$successMessage = JString::trim($this->params->get('success_message', ''));
						if (!empty($successMessage))
						{
							JFactory::getApplication()->enqueueMessage($successMessage);
						}
					}
					else
					{
						$failureMessage = JString::trim($this->params->get('failure_message', ''));
						if (!empty($failureMessage))
						{
							JFactory::getApplication()->enqueueMessage($failureMessage);
						}
					}

					return $finalResult;
				}
			}
		}
	}
}
